algolia_client_composition library

Classes

AgentSegment
Represents a segment of algolia agent header.
ApiClient
An abstract class representing an API client with specific properties and options.
ApiRequest
Represents an API request to be sent to Algolia.
BannerImage
BannerImageUrl
BaseInjectionQueryParameters
BaseSearchResponse
BatchParams
ClientOptions
Composition
CompositionBaseSearchResponse
CompositionClient
CompositionIdRankingInfo
CompositionInjectionBehavior
CompositionMultifeedBehavior
CompositionRankingInfo
CompositionRule
CompositionRuleConsequence
CompositionRulesBatchParams
CompositionRunAppliedRules
CompositionRunSearchResponse
CompositionsSearchResponse
Condition
Deduplication
DeleteCompositionAction
DeleteCompositionRuleAction
ErrorBase
Exhaustive
ExternalInjectedItem
ExternalInjection
FacetHits
FacetOrdering
FacetStats
FeedInjection
GetTaskResponse
HighlightResultOption
Hit
HitMetadata
HitRankingInfo
Host
Represents an Algolia host.
HttpRequest
Represents an Http request.
HttpResponse
Represents an Http response
IndexSettingsFacets
InjectedItemExternal
InjectedItemExternalSource
InjectedItemHitsMetadata
InjectedItemMetadata
InjectedItemRecommendSource
InjectedItemSearch
InjectedItemSearchSource
Injection
InjectionInjectedItem
InjectionMain
InjectionMainRecommendSource
InjectionMainSearchSource
ListCompositionsResponse
MainInjectionQueryParameters
MainRecommend
MainSearch
MatchedGeoLocation
Multifeed
MultipleBatchRequest
MultipleBatchResponse
Params
Personalization
Range
RankingInfo
Recommend
Redirect
RedirectRuleIndexData
RedirectRuleIndexMetadata
RedirectURL
RenderingContent
RequestBody
Requester
A contract Requester to define an interface for handling HTTP requests and responses.
RequestOptions
Represents options for configuring a request to an endpoint.
ResultsCompositionInfoResponse
ResultsCompositionsResponse
ResultsInjectedItemAppliedRulesInfoResponse
ResultsInjectedItemInfoResponse
RetryStrategy
Component to run http requests with retry logic.
RulesMultipleBatchRequest
RulesMultipleBatchResponse
SearchCompositionRulesParams
SearchCompositionRulesResponse
SearchFields
SearchForFacetValuesParams
SearchForFacetValuesRequest
SearchForFacetValuesResponse
SearchForFacetValuesResults
SearchResponse
SearchResults
SearchResultsItem
SnippetResultOption
TaskIDResponse
TimeRange
Value
Widgets

Enums

Action
Type of Composition Batch operation.
AdvancedSyntaxFeatures
AlternativesAsExact
Anchoring
Which part of the search query the pattern should match: - startsWith. The pattern must match the beginning of the query. - endsWith. The pattern must match the end of the query. - is. The pattern must match the query exactly. - contains. The pattern must match anywhere in the query. Empty queries are only allowed as patterns with anchoring: is.
AroundRadiusAll
Return all records with a valid _geoloc attribute. Don't filter by distance.
BooleanString
CallType
Indicate whether the HTTP call performed is of type read (GET) or write (POST, PUT ..). Used to determine which timeout duration to use.
DedupPositioning
Deduplication positioning configures how a duplicate result should be resolved between an injected item and main search results. Current configuration supports: - 'highest': always select the item in the highest position, and remove duplicates that appear lower in the results. - 'highestInjected': duplicate result will be moved to its highest possible injected position, but not higher. If a duplicate appears higher in main search results, it will be removed to stay it's intended group position (which could be lower than main).
ExactOnSingleWordQuery
Determines how the Exact ranking criterion is computed when the search query has only one word. - attribute. The Exact ranking criterion is 1 if the query word and attribute value are the same. For example, a search for "road" will match the value "road", but not "road trip". - none. The Exact ranking criterion is ignored on single-word searches. - word. The Exact ranking criterion is 1 if the query word is found in the attribute value. The query word must have at least 3 characters and must not be a stop word. Only exact matches will be highlighted, partial and prefix matches won't.
ExternalOrdering
Ordering to apply on the injected items coming from the external source. 'default' means the items will be ordered as they are in the index (natural relevance) in the smart group. 'userDefined' means the order in which the objectIDs are provided in the run request payload will be preserved in the smart group.
MatchLevel
Whether the whole query string matches or only a part.
Model
Recommendation model to use for retrieving recommendations.
QueryType
Determines if and how query words are interpreted as prefixes. By default, only the last query word is treated as a prefix (prefixLast). To turn off prefix search, use prefixNone. Avoid prefixAll, which treats all query words as prefixes. This might lead to counterintuitive results and makes your search slower. For more information, see Prefix searching.
RemoveWordsIfNoResults
Strategy for removing words from the query when it doesn't return any results. This helps to avoid returning empty search results. - none. No words are removed when a query doesn't return results. - lastWords. Treat the last (then second to last, then third to last) word as optional, until there are results or at most 5 words have been removed. - firstWords. Treat the first (then second, then third) word as optional, until there are results or at most 5 words have been removed. - allOptional. Treat all words as optional. For more information, see Remove words to improve results.
RequestMethod
Provides enumerated HTTP verbs
SortRemainingBy
Order of facet values that aren't explicitly positioned with the order setting. - count. Order remaining facet values by decreasing count. The count is the number of matching records containing this facet value. - alpha. Sort facet values alphabetically. - hidden. Don't show facet values that aren't explicitly positioned.
SupportedLanguage
ISO code for a supported language.
TaskStatus
Task status, published if the task is completed, notPublished otherwise.
TypoToleranceEnum
  • min. Return matches with the lowest number of typos. For example, if you have matches without typos, only include those. But if there are no matches without typos (with 1 typo), include matches with 1 typo (2 typos). - strict. Return matches with the two lowest numbers of typos. With strict, the Typo ranking criterion is applied first in the ranking setting.
  • Exceptions / Errors

    AlgoliaApiException
    Exception thrown when the Algolia API returns an error.
    AlgoliaException
    Abstract base class for all Algolia exceptions.
    AlgoliaIOException
    Exception thrown when there is an input/output error during a request to the Algolia API.
    AlgoliaTimeoutException
    Exception thrown when a request to the Algolia API times out.
    AlgoliaWaitException
    Exception thrown when an error occurs during the wait strategy. For example: maximum number of retry exceeded.
    UnreachableHostsException
    Exception thrown when all hosts for the Algolia API are unreachable.