BaseInjectionQueryParameters class final

Annotations
  • @JsonSerializable.new()

Constructors

BaseInjectionQueryParameters({bool? advancedSyntax, List<AdvancedSyntaxFeatures>? advancedSyntaxFeatures, bool? allowTyposOnNumericTokens, List<AlternativesAsExact>? alternativesAsExact, bool? attributeCriteriaComputedByMinProximity, List<String>? attributesToHighlight, List<String>? attributesToRetrieve, List<String>? attributesToSnippet, bool? clickAnalytics, List<String>? disableExactOnAttributes, List<String>? disableTypoToleranceOnAttributes, dynamic distinct, bool? enableABTest, bool? enablePersonalization, bool? enableReRanking, bool? enableRules, ExactOnSingleWordQuery? exactOnSingleWordQuery, dynamic facetFilters, String? filters, bool? getRankingInfo, String? highlightPostTag, String? highlightPreTag, dynamic ignorePlurals, int? minProximity, int? minWordSizefor1Typo, int? minWordSizefor2Typos, List<SupportedLanguage>? naturalLanguages, dynamic numericFilters, dynamic optionalFilters, dynamic optionalWords, bool? percentileComputation, int? personalizationImpact, List<SupportedLanguage>? queryLanguages, QueryType? queryType, dynamic removeStopWords, RemoveWordsIfNoResults? removeWordsIfNoResults, bool? replaceSynonymsInHighlight, List<String>? responseFields, bool? restrictHighlightAndSnippetArrays, List<String>? restrictSearchableAttributes, List<String>? ruleContexts, String? snippetEllipsisText, bool? synonyms, dynamic typoTolerance})
Returns a new BaseInjectionQueryParameters instance.
const
BaseInjectionQueryParameters.fromJson(Map<String, dynamic> json)
factory

Properties

advancedSyntax bool?
Whether to support phrase matching and excluding words from search queries Use the advancedSyntaxFeatures parameter to control which feature is supported.
final
advancedSyntaxFeatures List<AdvancedSyntaxFeatures>?
Advanced search syntax features you want to support - exactPhrase. Phrases in quotes must match exactly. For example, sparkly blue \"iPhone case\" only returns records with the exact string "iPhone case" - excludeWords. Query words prefixed with a - must not occur in a record. For example, search -engine matches records that contain "search" but not "engine" This setting only has an effect if advancedSyntax is true.
final
allowTyposOnNumericTokens bool?
Whether to allow typos on numbers in the search query Turn off this setting to reduce the number of irrelevant matches when searching in large sets of similar numbers.
final
alternativesAsExact List<AlternativesAsExact>?
Determine which plurals and synonyms should be considered an exact matches By default, Algolia treats singular and plural forms of a word, and single-word synonyms, as exact matches when searching. For example - "swimsuit" and "swimsuits" are treated the same - "swimsuit" and "swimwear" are treated the same (if they are synonyms) - ignorePlurals. Plurals and similar declensions added by the ignorePlurals setting are considered exact matches - singleWordSynonym. Single-word synonyms, such as "NY" = "NYC", are considered exact matches - multiWordsSynonym. Multi-word synonyms, such as "NY" = "New York", are considered exact matches.
final
attributeCriteriaComputedByMinProximity bool?
Whether the best matching attribute should be determined by minimum proximity This setting only affects ranking if the Attribute ranking criterion comes before Proximity in the ranking setting. If true, the best matching attribute is selected based on the minimum proximity of multiple matches. Otherwise, the best matching attribute is determined by the order in the searchableAttributes setting.
final
attributesToHighlight List<String>?
Attributes to highlight By default, all searchable attributes are highlighted. Use * to highlight all attributes or use an empty array [] to turn off highlighting. Attribute names are case-sensitive With highlighting, strings that match the search query are surrounded by HTML tags defined by highlightPreTag and highlightPostTag. You can use this to visually highlight matching parts of a search query in your UI For more information, see Highlighting and snippeting.
final
attributesToRetrieve List<String>?
Attributes to include in the API response To reduce the size of your response, you can retrieve only some of the attributes. Attribute names are case-sensitive - * retrieves all attributes, except attributes included in the customRanking and unretrievableAttributes settings. - To retrieve all attributes except a specific one, prefix the attribute with a dash and combine it with the *: [\"*\", \"-ATTRIBUTE\"]. - The objectID attribute is always included.
final
attributesToSnippet List<String>?
Attributes for which to enable snippets. Attribute names are case-sensitive Snippets provide additional context to matched words. If you enable snippets, they include 10 words, including the matched word. The matched word will also be wrapped by HTML tags for highlighting. You can adjust the number of words with the following notation: ATTRIBUTE:NUMBER, where NUMBER is the number of words to be extracted.
final
clickAnalytics bool?
Whether to include a queryID attribute in the response The query ID is a unique identifier for a search query and is required for tracking click and conversion events.
final
disableExactOnAttributes List<String>?
Searchable attributes for which you want to turn off the Exact ranking criterion. Attribute names are case-sensitive This can be useful for attributes with long values, where the likelihood of an exact match is high, such as product descriptions. Turning off the Exact ranking criterion for these attributes favors exact matching on other attributes. This reduces the impact of individual attributes with a lot of content on ranking.
final
disableTypoToleranceOnAttributes List<String>?
Attributes for which you want to turn off typo tolerance. Attribute names are case-sensitive Returning only exact matches can help when - Searching in hyphenated attributes. - Reducing the number of matches when you have too many. This can happen with attributes that are long blocks of text, such as product descriptions Consider alternatives such as disableTypoToleranceOnWords or adding synonyms if your attributes have intentional unusual spellings that might look like typos.
final
distinct → dynamic
One of types:
final
enableABTest bool?
Whether to enable A/B testing for this search.
final
enablePersonalization bool?
Whether to enable Personalization.
final
enableReRanking bool?
Whether this search will use Dynamic Re-Ranking This setting only has an effect if you activated Dynamic Re-Ranking for this index in the Algolia dashboard.
final
enableRules bool?
Whether to enable rules.
final
exactOnSingleWordQuery ExactOnSingleWordQuery?
final
facetFilters → dynamic
One of types:
final
filters String?
Filter expression to only include items that match the filter criteria in the response. You can use these filter expressions: - Numeric filters. <facet> <op> <number>, where <op> is one of <, <=, =, !=, >, >=. - Ranges. <facet>:<lower> TO <upper>, where <lower> and <upper> are the lower and upper limits of the range (inclusive). - Facet filters. <facet>:<value>, where <facet> is a facet attribute (case-sensitive) and <value> a facet value. - Tag filters. _tags:<value> or just <value> (case-sensitive). - Boolean filters. <facet>: true | false. You can combine filters with AND, OR, and NOT operators with the following restrictions: - You can only combine filters of the same type with OR. Not supported: facet:value OR num > 3. - You can't use NOT with combinations of filters. Not supported: NOT(facet:value OR facet:value) - You can't combine conjunctions (AND) with OR. Not supported: facet:value OR (facet:value AND facet:value) Use quotes if the facet attribute name or facet value contains spaces, keywords (OR, AND, NOT), or quotes. If a facet attribute is an array, the filter matches if it matches at least one element of the array. For more information, see Filters.
final
getRankingInfo bool?
Whether the search response should include detailed ranking information.
final
hashCode int
The hash code for this object.
no setteroverride
highlightPostTag String?
HTML tag to insert after the highlighted parts in all highlighted results and snippets.
final
highlightPreTag String?
HTML tag to insert before the highlighted parts in all highlighted results and snippets.
final
ignorePlurals → dynamic
One of types:
final
minProximity int?
Minimum proximity score for two matching words This adjusts the Proximity ranking criterion by equally scoring matches that are farther apart For example, if minProximity is 2, neighboring matches and matches with one word between them would have the same score.
final
minWordSizefor1Typo int?
Minimum number of characters a word in the search query must contain to accept matches with one typo.
final
minWordSizefor2Typos int?
Minimum number of characters a word in the search query must contain to accept matches with two typos.
final
naturalLanguages List<SupportedLanguage>?
ISO language codes that adjust settings that are useful for processing natural language queries (as opposed to keyword searches) - Sets removeStopWords and ignorePlurals to the list of provided languages. - Sets removeWordsIfNoResults to allOptional. - Adds a natural_language attribute to ruleContexts and analyticsTags.
final
numericFilters → dynamic
One of types:
final
optionalFilters → dynamic
One of types:
final
optionalWords → dynamic
One of types:
final
percentileComputation bool?
Whether to include this search when calculating processing-time percentiles.
final
personalizationImpact int?
Impact that Personalization should have on this search The higher this value is, the more Personalization determines the ranking compared to other factors. For more information, see Understanding Personalization impact.
final
queryLanguages List<SupportedLanguage>?
Languages for language-specific query processing steps such as plurals, stop-word removal, and word-detection dictionaries. This setting sets a default list of languages used by the removeStopWords and ignorePlurals settings. This setting also sets a dictionary for word detection in the logogram-based CJK languages. To support this, place the CJK language first. Always specify a query language. If you don't specify an indexing language, the search engine uses all supported languages, or the languages you specified with the ignorePlurals or removeStopWords parameters. This can lead to unexpected search results. For more information, see Language-specific configuration.
final
queryType QueryType?
final
removeStopWords → dynamic
One of types:
final
removeWordsIfNoResults RemoveWordsIfNoResults?
final
replaceSynonymsInHighlight bool?
Whether to replace a highlighted word with the matched synonym By default, the original words are highlighted even if a synonym matches. For example, with home as a synonym for house and a search for home, records matching either "home" or "house" are included in the search results, and either "home" or "house" are highlighted With replaceSynonymsInHighlight set to true, a search for home still matches the same records, but all occurrences of "house" are replaced by "home" in the highlighted response.
final
responseFields List<String>?
Properties to include in the API response of search and browse requests By default, all response properties are included. To reduce the response size, you can select which properties should be included An empty list may lead to an empty API response (except properties you can't exclude) You can't exclude these properties: message, warning, cursor, abTestVariantID, or any property added by setting getRankingInfo to true Your search depends on the hits field. If you omit this field, searches won't return any results. Your UI might also depend on other properties, for example, for pagination. Before restricting the response size, check the impact on your search experience.
final
restrictHighlightAndSnippetArrays bool?
Whether to restrict highlighting and snippeting to items that at least partially matched the search query. By default, all items are highlighted and snippeted.
final
restrictSearchableAttributes List<String>?
Restricts a search to a subset of your searchable attributes. Attribute names are case-sensitive.
final
ruleContexts List<String>?
Assigns a rule context to the search query Rule contexts are strings that you can use to trigger matching rules.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snippetEllipsisText String?
String used as an ellipsis indicator when a snippet is truncated.
final
synonyms bool?
Whether to take into account an index's synonyms for this search.
final
typoTolerance → dynamic
One of types:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override