CompositionRulesBatchParams class final

Annotations
  • @JsonSerializable.new()

Constructors

CompositionRulesBatchParams({List<RulesMultipleBatchRequest>? requests})
Returns a new CompositionRulesBatchParams instance.
const
CompositionRulesBatchParams.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
requests List<RulesMultipleBatchRequest>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override