Condition class final

Annotations
  • @JsonSerializable.new()

Constructors

Condition({String? pattern, Anchoring? anchoring, String? context, String? filters, String? sortBy})
Returns a new Condition instance.
const
Condition.fromJson(Map<String, dynamic> json)
factory

Properties

anchoring Anchoring?
final
context String?
An additional restriction that only triggers the rule, when the search has the same value as ruleContexts parameter. For example, if context: mobile, the rule is only triggered when the search request has a matching ruleContexts: mobile. A rule context must only contain alphanumeric characters.
final
filters String?
Filters that trigger the rule. You can add add filters using the syntax facet:value so that the rule is triggered, when the specific filter is selected. You can use filters on its own or combine it with the pattern parameter.
final
hashCode int
The hash code for this object.
no setteroverride
pattern String?
Query pattern that triggers the rule. You can use either a literal string, or a special pattern {facet:ATTRIBUTE}, where ATTRIBUTE is a facet name. The rule is triggered if the query matches the literal string or a value of the specified facet. For example, with pattern: {facet:genre}, the rule is triggered when users search for a genre, such as "comedy".
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortBy String?
Sort criteria that trigger the rule. You can trigger composition rules based on the selected sorting strategy set by the parameter sortBy. The rule will trigger if the value passed to sortBy matches the one defined in the condition.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override