MultipleBatchResponse class final

Annotations
  • @JsonSerializable.new()

Constructors

MultipleBatchResponse({required Map<String, int> taskID})
Returns a new MultipleBatchResponse instance.
const
MultipleBatchResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskID Map<String, int>
Task IDs. One for each index.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override