Params class final

Annotations
  • @JsonSerializable.new()

Constructors

Params({bool? analytics, List<String>? analyticsTags, String? aroundLatLng, bool? aroundLatLngViaIP, dynamic aroundRadius, dynamic aroundPrecision, bool? clickAnalytics, bool? enableABTest, bool? enablePersonalization, bool? enableReRanking, bool? enableRules, dynamic facetFilters, List<String>? facets, String? filters, bool? getRankingInfo, int? hitsPerPage, Map<String, ExternalInjectedItem>? injectedItems, dynamic insideBoundingBox, List<List<double>>? insidePolygon, int? minimumAroundRadius, List<SupportedLanguage>? naturalLanguages, dynamic numericFilters, dynamic optionalFilters, int? page, String? query, List<SupportedLanguage>? queryLanguages, int? relevancyStrictness, List<String>? ruleContexts, String? sortBy, String? userToken})
Returns a new Params instance.
const
Params.fromJson(Map<String, dynamic> json)
factory

Properties

analytics bool?
Whether this search will be included in Analytics.
final
analyticsTags List<String>?
Tags to apply to the query for segmenting analytics data.
final
aroundLatLng String?
Coordinates for the center of a circle, expressed as a comma-separated string of latitude and longitude. Only records included within a circle around this central location are included in the results. The radius of the circle is determined by the aroundRadius and minimumAroundRadius settings. This parameter is ignored if you also specify insidePolygon or insideBoundingBox.
final
aroundLatLngViaIP bool?
Whether to obtain the coordinates from the request's IP address.
final
aroundPrecision → dynamic
One of types:
final
aroundRadius → dynamic
One of types:
final
clickAnalytics bool?
Whether to include a queryID attribute in the response The query ID is a unique identifier for a search query and is required for tracking click and conversion events.
final
enableABTest bool?
Whether to enable index level A/B testing for this run request. If the composition mixes multiple indices, the A/B test is ignored.
final
enablePersonalization bool?
Whether to enable Personalization.
final
enableReRanking bool?
Whether this search will use Dynamic Re-Ranking This setting only has an effect if you activated Dynamic Re-Ranking for this index in the Algolia dashboard.
final
enableRules bool?
Whether to enable composition rules.
final
facetFilters → dynamic
One of types:
final
facets List<String>?
Facets for which to retrieve facet values that match the search criteria and the number of matching facet values To retrieve all facets, use the wildcard character *. To retrieve disjunctive facets lists, annotate any facets with the disjunctive modifier. For more information, see facets and disjunctive faceting for Smart Groups.
final
filters String?
Filter expression to only include items that match the filter criteria in the response. You can use these filter expressions: - Numeric filters. <facet> <op> <number>, where <op> is one of <, <=, =, !=, >, >=. - Ranges. <facet>:<lower> TO <upper>, where <lower> and <upper> are the lower and upper limits of the range (inclusive). - Facet filters. <facet>:<value>, where <facet> is a facet attribute (case-sensitive) and <value> a facet value. - Tag filters. _tags:<value> or just <value> (case-sensitive). - Boolean filters. <facet>: true | false. You can combine filters with AND, OR, and NOT operators with the following restrictions: - You can only combine filters of the same type with OR. Not supported: facet:value OR num > 3. - You can't use NOT with combinations of filters. Not supported: NOT(facet:value OR facet:value) - You can't combine conjunctions (AND) with OR. Not supported: facet:value OR (facet:value AND facet:value) Use quotes if the facet attribute name or facet value contains spaces, keywords (OR, AND, NOT), or quotes. If a facet attribute is an array, the filter matches if it matches at least one element of the array. For more information, see Filters.
final
getRankingInfo bool?
Whether the run response should include detailed ranking information.
final
hashCode int
The hash code for this object.
no setteroverride
hitsPerPage int?
Number of hits per page.
final
injectedItems Map<String, ExternalInjectedItem>?
An object containing keys corresponding to the keys from an injection's injectedItems and values containing a list of hits to inject.
final
insideBoundingBox → dynamic
One of types:
final
insidePolygon List<List<double>>?
Coordinates of a polygon in which to search. Polygons are defined by 3 to 10,000 points. Each point is represented by its latitude and longitude. Provide multiple polygons as nested arrays. For more information, see filtering inside polygons. This parameter is ignored if you also specify insideBoundingBox.
final
minimumAroundRadius int?
Minimum radius (in meters) for a search around a location when aroundRadius isn't set.
final
naturalLanguages List<SupportedLanguage>?
ISO language codes that adjust settings that are useful for processing natural language queries (as opposed to keyword searches) - Sets removeStopWords and ignorePlurals to the list of provided languages. - Sets removeWordsIfNoResults to allOptional. - Adds a natural_language attribute to ruleContexts and analyticsTags.
final
numericFilters → dynamic
One of types:
final
optionalFilters → dynamic
One of types:
final
page int?
Page of search results to retrieve.
final
query String?
Search query.
final
queryLanguages List<SupportedLanguage>?
Languages for language-specific query processing steps such as plurals, stop-word removal, and word-detection dictionaries. This setting sets a default list of languages used by the removeStopWords and ignorePlurals settings. This setting also sets a dictionary for word detection in the logogram-based CJK languages. To support this, place the CJK language first. Always specify a query language. If you don't specify an indexing language, the search engine uses all supported languages, or the languages you specified with the ignorePlurals or removeStopWords parameters. This can lead to unexpected search results. For more information, see Language-specific configuration.
final
relevancyStrictness int?
Relevancy threshold below which less relevant results aren't included in the results You can only set relevancyStrictness on virtual replica indices. Use this setting to strike a balance between the relevance and number of returned results.
final
ruleContexts List<String>?
Assigns a rule context to the run query Rule contexts are strings that you can use to trigger matching rules.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortBy String?
Indicates which sorting strategy to apply for the request. The value must match one of the labels defined in the "sortingStrategy" mapping. For example, "Price (asc)", see Upsert Composition. At runtime, this label is used to look up the corresponding index or replica configured in "sortingStrategy", and the query is executed using that index instead of main's. In addition to "sortingStrategy", this parameter is also used to apply a matching Composition Rule that contains a condition defined to trigger on "sortBy", see Composition Rules. If no value is provided or an invalid value, no sorting strategy is applied.
final
userToken String?
Unique pseudonymous or anonymous user identifier. This helps with analytics and click and conversion events. For more information, see user token.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override