RulesMultipleBatchRequest class final

Annotations
  • @JsonSerializable.new()

Constructors

RulesMultipleBatchRequest({required Action action, required dynamic body})
Returns a new RulesMultipleBatchRequest instance.
const
RulesMultipleBatchRequest.fromJson(Map<String, dynamic> json)
factory

Properties

action Action
final
body → dynamic
One of types:
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override