An additional restriction that only triggers the rule, when the search has the same value as ruleContexts parameter. For example, if context: mobile, the rule is only triggered when the search request has a matching ruleContexts: mobile. A rule context must only contain alphanumeric characters.
Filters that trigger the rule. You can add add filters using the syntax facet:value so that the rule is triggered, when the specific filter is selected. You can use filters on its own or combine it with the pattern parameter.
Query pattern that triggers the rule. You can use either a literal string, or a special pattern {facet:ATTRIBUTE}, where ATTRIBUTE is a facet name. The rule is triggered if the query matches the literal string or a value of the specified facet. For example, with pattern: {facet:genre}, the rule is triggered when users search for a genre, such as "comedy".
Sort criteria that trigger the rule. You can trigger composition rules based on the selected sorting strategy set by the parameter sortBy. The rule will trigger if the value passed to sortBy matches the one defined in the condition.