InjectedItemHitsMetadata class final
- Annotations
-
- @JsonSerializable.new()
Constructors
-
InjectedItemHitsMetadata({bool? addItemKey, Map<
String, Object> ? extra}) -
Returns a new InjectedItemHitsMetadata instance.
const
-
InjectedItemHitsMetadata.fromJson(Map<
String, dynamic> json) -
factory
Properties
- addItemKey → bool?
-
When true, the
_injectedItemKeyfield is set in the_extraobject of each affected hit.final -
extra
→ Map<
String, Object> ? -
The user-defined key-value pairs that will be placed in the
_extrafield of each affected hit.final - hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override