Coordinates for the center of a circle, expressed as a comma-separated string of latitude and longitude. Only records included within a circle around this central location are included in the results. The radius of the circle is determined by the aroundRadius and minimumAroundRadius settings. This parameter is ignored if you also specify insidePolygon or insideBoundingBox.
Whether to include a queryID attribute in the response The query ID is a unique identifier for a search query and is required for tracking click and conversion events.
Whether this search will use Dynamic Re-Ranking This setting only has an effect if you activated Dynamic Re-Ranking for this index in the Algolia dashboard.
Facets for which to retrieve facet values that match the search criteria and the number of matching facet values To retrieve all facets, use the wildcard character *. To retrieve disjunctive facets lists, annotate any facets with the disjunctive modifier. For more information, see facets and disjunctive faceting for Smart Groups.
Filter expression to only include items that match the filter criteria in the response. You can use these filter expressions: - Numeric filters.<facet> <op> <number>, where <op> is one of <, <=, =, !=, >, >=. - Ranges.<facet>:<lower> TO <upper>, where <lower> and <upper> are the lower and upper limits of the range (inclusive). - Facet filters.<facet>:<value>, where <facet> is a facet attribute (case-sensitive) and <value> a facet value. - Tag filters._tags:<value> or just <value> (case-sensitive). - Boolean filters.<facet>: true | false. You can combine filters with AND, OR, and NOT operators with the following restrictions: - You can only combine filters of the same type with OR. Not supported:facet:value OR num > 3. - You can't use NOT with combinations of filters. Not supported:NOT(facet:value OR facet:value) - You can't combine conjunctions (AND) with OR. Not supported:facet:value OR (facet:value AND facet:value) Use quotes if the facet attribute name or facet value contains spaces, keywords (OR, AND, NOT), or quotes. If a facet attribute is an array, the filter matches if it matches at least one element of the array. For more information, see Filters.
Coordinates of a polygon in which to search. Polygons are defined by 3 to 10,000 points. Each point is represented by its latitude and longitude. Provide multiple polygons as nested arrays. For more information, see filtering inside polygons. This parameter is ignored if you also specify insideBoundingBox.
ISO language codes that adjust settings that are useful for processing natural language queries (as opposed to keyword searches) - Sets removeStopWords and ignorePlurals to the list of provided languages. - Sets removeWordsIfNoResults to allOptional. - Adds a natural_language attribute to ruleContexts and analyticsTags.
Languages for language-specific query processing steps such as plurals, stop-word removal, and word-detection dictionaries. This setting sets a default list of languages used by the removeStopWords and ignorePlurals settings. This setting also sets a dictionary for word detection in the logogram-based CJK languages. To support this, place the CJK language first. Always specify a query language. If you don't specify an indexing language, the search engine uses all supported languages, or the languages you specified with the ignorePlurals or removeStopWords parameters. This can lead to unexpected search results. For more information, see Language-specific configuration.
Relevancy threshold below which less relevant results aren't included in the results You can only set relevancyStrictness on virtual replica indices. Use this setting to strike a balance between the relevance and number of returned results.
Indicates which sorting strategy to apply for the request. The value must match one of the labels defined in the "sortingStrategy" mapping. For example, "Price (asc)", see Upsert Composition. At runtime, this label is used to look up the corresponding index or replica configured in "sortingStrategy", and the query is executed using that index instead of main's. In addition to "sortingStrategy", this parameter is also used to apply a matching Composition Rule that contains a condition defined to trigger on "sortBy", see Composition Rules. If no value is provided or an invalid value, no sorting strategy is applied.